#!/bin/sh
#*MH******************************************************************
# MOD-NAME     : rcAShg3550m.sh          VAR./VERSION:  HP4KXANK/002 *
# LONG-NAME    : rc script of AShg3550m                              *
# AUTHOR       : Sedar Gokbulut (SG)                                 *
# DEPARTMENT   : Siemens PSE - TR (Ankara)                           *
# TELEPHONE    : +90 (312) 292 6123                                  *
# CREATION-DATE: 27th December 2005                                  *
# SP-NO        :                                                     *
# FUNCTION     :                                                     *
# NOTES        : Unity HG3550 v2 Manager                             *
# STRUCTURE    :                                                     *
# SUBSYSTEM    : AShg3550m                                           *
# INT-STRUCTURE:                                                     *
# EXT-STRUCTURE:                                                     *
# FILES        :                                                     *
#*********************************************************************
#*HOC*****************************************************************
#                                                                    *
# HISTORY OF CHANGE:                      VARIANT:  HP4KXANK         *
#                                                                    *
#------+------+-----------------------------------------+-----+------*
# VERS | DATE | CHANGES                                 |AUTH | CNO  *
#      |YYMMDD|                                         |     |      *
#--------------------------------------------------------------------*
#  001 |051228|Initial Creation                         |SG   |G58894*
#  002 |051228|Create label                             |SG   |G58894*
#--------------------------------------------------------------------*
#*********************************************************************

### BEGIN INIT INFO
# Provides:     AShg3550m
# Required-Start:
# Required-Stop:
# Should-Start: $ALL
# Default-Start: 3 5
# Default-Stop: 0
# Description:  Start script of HG3550M 
### END INIT INFO


# ====================================================================
# global values
# --------------------------------------------------------------------

# the log file
F_LOG="/var/hg3550m/log/rc.log"
# Configuration Backup Lock File
F_CFG_LOCK="/var/hg3550m/conf/configBackupProcess"

# the command to get the platform type
X_GETHINFO="/opt/bin/gethinfo"
#rollback directory and files
D_ROLLBACK="/var/hg3550m/tmp/rollback/"
F_ROLLBACK="/var/hg3550m/tmp/rollback/*"
#backup directory
D_CFGBACKUP="/var/hg3550m/htdocs/backup/"
F_CFGBACKUP="/var/hg3550m/htdocs/backup/*"

# ====================================================================
# commonly used functions
# --------------------------------------------------------------------

# restrict file <name> to at most <siz> bytes
# chkfilsiz(name, siz)
chkfilsiz() {
    [ -f "$1" ] && {
        [ `cat "$1" | wc -c` -gt "$2" ] && {
            mv "$1" "$1-"
            touch "$1"
        }
    }
}

# ====================================================================
# main()
# --------------------------------------------------------------------

# say "here I am"
chkfilsiz "$F_LOG" 65536
echo "=== $1 `date`" >> "$F_LOG"


# get the platform type
if [ -x "$X_GETHINFO" ]; then
    pf=`"$X_GETHINFO" -a`
else
    pf="unknown"
fi
case "$pf" in
    AS-L|AS-N|HTS)
        # these are expected values
        platform="$pf"
        echo "Known platform ($pf) " >> "$F_LOG"
        ;;
    *)
        # these aren't :-(
        # --> we default to AS-L scenario
        echo "WARNING: unkown platform ($pf) - assuming \"AS-L\"" >> "$F_LOG"
        platform="AS-L"
        ;;
esac
export platform

# the action itself
case "$1" in
    stop)
        # To be safe, AShg3550m works on ADP only
        [ "$platform" = "AS-L" ] && {
            if [ -f "$F_CFG_LOCK" ]; then
                echo "WARNING: Backup shall have been interrupted by reboot. Script will rollback backup" >> "$F_LOG"
		_RET=`rm "$F_CFG_LOCK" 2>&1`
		[ "$?" -ne 0 ] && {
			echo "ERROR:   Unable to remove $F_CFG_LOCK: [$_RET]" >> "$F_LOG"
		}
		_RET=`cp $F_ROLLBACK $D_CFGBACKUP 2>&1`
		[ "$?" -ne 0 ] && {
			echo "ERROR-$?:Unable to rollback backup files:" >> "$F_LOG"
			echo "[$_RET]" >> "$F_LOG"
		}
		`chgrp unity $F_CFGBACKUP`
		`chmod 666 $F_CFGBACKUP`
            fi
        }
        ;;
    start)
        # up to now nothing is to be done
        ;;
    restart)
        $0 stop &&
            $0 start
        ;;
    *)
        echo "Usage: $0 {start|stop|restart}" >&2
        echo "USAGE: \"$*\"" >> "$F_LOG"
        exit 1
esac

# say "Good bye"
echo "--- `date` --- Done." >> "$F_LOG"

exit 0
# ====================================================================

